from setuptools import setup, find_packages

setup(
    name="strx-docgen",
    version="0.1.1",
    url="https://github.com/straconxsa/strx_tools/",
    project_urls={
        "Bug Tracker": "https://github.com/straconxsa/strx_tools/issues",
    },
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    include_package_data=True,
    package_data={
        "strx_docgen": ["templates/*.html"],
    },
    install_requires=[
        "click",
        "jinja2",
        "markdown",
    ],
    entry_points={
        "console_scripts": [
            "strx-docgen=strx_docgen.generator:cli",
        ],
    },
)
